@@ -1,16 +1,16 @@
+from __future__ import annotations
+
 import logging
 import pathlib
 import textwrap
-from typing import Optional, Tuple
+from typing import Callable
 
-import mkdocs.utils
 from jinja2 import BaseLoader, Environment
 
 __all__ = ["TemplateRewritingLoader"]
 
 
 log = logging.getLogger(f"mkdocs.plugins.{__name__}")
-log.addFilter(mkdocs.utils.warning_filter)
 
 
 class TemplateRewritingLoader(BaseLoader):
@@ -18,9 +18,13 @@ class TemplateRewritingLoader(BaseLoader):
         self.loader = loader
         self.found_supported_theme = False
 
-    def get_source(self, environment: Environment, template: str) -> Tuple[str, str, bool]:
+    def get_source(
+        self, environment: Environment, template: str
+    ) -> tuple[str, str, Callable[[], bool] | None]:
+        src: str | None
         src, filename, uptodate = self.loader.get_source(environment, template)
         old_src = src
+        assert filename is not None
         path = pathlib.Path(filename).as_posix()
 
         if path.endswith("/mkdocs/templates/sitemap.xml"):
@@ -44,13 +48,14 @@ class TemplateRewritingLoader(BaseLoader):
         return src or old_src, filename, uptodate
 
 
-def _transform_mkdocs_sitemap_template(src: str) -> Optional[str]:
+def _transform_mkdocs_sitemap_template(src: str) -> str | None:
     if " in pages " not in src:
         # The below only for versions <= 1.1.2.
         return src.replace(
             "{%- else %}",
             "{%- endif %}{% if item.url %}",
         )
+    return None
 
 
 def _transform_material_nav_item_template(src: str) -> str:
@@ -58,6 +63,9 @@ def _transform_material_nav_item_template(src: str) -> str:
         return src.replace(
             "{% set indexes = [] %}",
             "{% set indexes = [nav_item] if nav_item.url else [] %}",
+        ).replace(
+            "{% if nav_item.children | length > 1 %}",
+            "{% if nav_item.children %}",
         )
 
     # The above only for versions >= 7.3, the below only for versions < 7.3.
@@ -116,7 +124,7 @@ def _transform_readthedocs_base_template(src: str) -> str:
     return "\n".join(lines)
 
 
-def _replace_line(line: str, wrapper: str, new_line: Optional[str] = None) -> str:
+def _replace_line(line: str, wrapper: str, new_line: str | None = None) -> str:
     leading_space = line[: -len(line.lstrip())]
     if new_line is None:
         new_line = line.lstrip()
